# -*- coding: UTF-8 -*

"""Notes, décisions de jury, évènements scolaires
"""

from app import db
from app.models import SHORT_STR_LEN
from app.models import CODE_STR_LEN


class BulAppreciations(db.Model):
    """Appréciations sur bulletins"""

    __tablename__ = "notes_appreciations"
    id = db.Column(db.Integer, primary_key=True)
    date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
        index=True,
    )
    formsemestre_id = db.Column(
        db.Integer,
        db.ForeignKey("notes_formsemestre.id"),
    )
    author = db.Column(db.Text)  # le pseudo (user_name), sans contrainte
    comment = db.Column(db.Text)  # texte libre


class NotesNotes(db.Model):
    """Une note"""

    __tablename__ = "notes_notes"
    __table_args__ = (db.UniqueConstraint("etudid", "evaluation_id"),)
    id = db.Column(db.Integer, primary_key=True)
    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
    )
    evaluation_id = db.Column(
        db.Integer, db.ForeignKey("notes_evaluation.id"), index=True
    )
    value = db.Column(db.Float)
    # infos sur saisie de cette note:
    comment = db.Column(db.Text)  # texte libre
    date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    uid = db.Column(db.Integer, db.ForeignKey("user.id"))


class NotesNotesLog(db.Model):
    """Historique des modifs sur notes (anciennes entrees de notes_notes)"""

    __tablename__ = "notes_notes_log"
    id = db.Column(db.Integer, primary_key=True)

    etudid = db.Column(
        db.Integer,
        db.ForeignKey("identite.id"),
    )
    evaluation_id = db.Column(
        db.Integer,
        # db.ForeignKey("notes_evaluation.id"),
        index=True,
    )
    value = db.Column(db.Float)
    # infos sur saisie de cette note:
    comment = db.Column(db.Text)  # texte libre
    date = db.Column(db.DateTime(timezone=True), server_default=db.func.now())
    uid = db.Column(db.Integer, db.ForeignKey("user.id"))
